@@ -5,8 +5,7 @@ import time
 
 # construct a function that loads my openai API key from home and then calls it
 def load_api_key(api_key_file):
-    with open(api_key_file, 'r') as f:
-        api_key = f.readline().strip()
+    api_key = json.loads(open(api_key_file).read())['cai_key']
     return api_key
 
 # construct a function that calls the openai codex and returns the results
@@ -28,7 +27,7 @@ def get_cai_suggestions(query: str, n_suggestions: int = 5):
     # measure timing 
     start = time.time()
     # get the api key from the home directory 
-    api_path = os.path.join(os.path.expanduser('~'), '.codex_api_key')
+    api_path = os.path.join(os.path.expanduser('~'), 'dt_config.json')
     api_key = load_api_key(api_path)
     response = constuct_call(api_key, query)
     after = time.time()
