@@ -13,12 +13,6 @@ def download_file_from_google_drive(id, destination):
     session = requests.Session()
 
     response = session.get(URL, params={'id': id}, stream=True)
-    # token = get_confirm_token(response)
-
-    # if token:
-        # params = {'id': id, 'confirm': token}
-        # response = session.get(URL, params=params, stream=True)
-    
     
     # parse response using re to look for html tag id="downloadForm"
     match = re.search(r'id="downloadForm" action="(.+?)"',
@@ -42,16 +36,4 @@ def download_file_from_google_drive(id, destination):
                 f.write(data)
     progress_bar.close()
     if total_size_in_bytes != 0 and progress_bar.n != total_size_in_bytes:
-        print("ERROR, something went wrong")
-    
-
-
-
-def main():
-    file_id = sys.argv[1]
-    destination = sys.argv[2]
-    download_file_from_google_drive(file_id, destination)
-
-
-# if __name__ == "__main__":
-#     main()
\ No newline at end of file
+        print("ERROR, something went wrong")
\ No newline at end of file
