@@ -1,5 +1,7 @@
 import re
 from collections import defaultdict, namedtuple
+import pandas as pd
+from pyparsing import line
 
 from ..ext.ssh_params import KNOWN_PARAMS
 
@@ -17,20 +19,17 @@ def print_ls(ssh_config):
     lines = [ l for l in ssh_config.lines_ if len(str(l).strip()) > 0 ]
     
     for i in range(len(lines))[::4]:
-        try:
-            host_name = lines[i].value
-            assert "Host" in lines[i].key
-            ip_address = lines[i + 1].value
-            assert "HostName" in lines[i + 1].key
-            identity_file = lines[i + 2].value
-            assert "IdentityFile" in lines[i + 2].key
-            user = lines[i + 3].value
-        except:
-            import ipdb; ipdb.set_trace()
-            
-        host.append([host_name, ip_address, user])
+        entry_dict = {
+            lines[i].key: lines[i].value,
+            lines[i + 1].key: lines[i + 1].value,
+            lines[i + 2].key: lines[i + 2].value,
+            lines[i + 3].key: lines[i + 3].value,
+        }
+        
+        # host.append([host_name, ip_address, user])
+        host.append(entry_dict)
 
-    df = pd.DataFrame(host, columns=["host", "ip", "user"])
+    df = pd.DataFrame(host)
     print(df)
 
 
